"""irMagician HTTP Server.

This module builds on SimpleHTTPServer by implementing the standard GET
and HEAD requests to json data for irMagician.

"""


__version__ = "0.1"

__all__ = ["irMagicianHTTPRequestHandler"]

import BaseHTTPServer
import SimpleHTTPServer
import serial
import json


ser = serial.Serial("/dev/ttyACM0", 9600, timeout = 1)
ser.readline()

class irMagicianHTTPRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):

    server_version = "irMagicianHTTP/" + __version__

    def do_GET(self):
        """Serve a GET request."""
        f = self.send_head()
        if f:
            self.ir_play(f);
            f.close()
            self.wfile.write("\r\n")

    def ir_play(self, f):
        """Send IR signal to irMagician.""" 
        json_data = json.load(f)

        recNumber = len(json_data['data'])
        rawX = json_data['data']

        ser.write("n,%d\r\n" % recNumber)
        ser.readline()

        postScale = json_data['postscale']
        ser.write("k,%d\r\n" % postScale)
        ser.readline()

        for n in range(recNumber):
            bank = n / 64
            pos = n % 64
            if (pos == 0):
    	        ser.write("b,%d\r\n" % bank)

            ser.write("w,%d,%d\n\r" % (pos, rawX[n]))

        ser.write("p\r\n")
        ser.readline()

def test(HandlerClass = irMagicianHTTPRequestHandler,
         ServerClass = BaseHTTPServer.HTTPServer):
    SimpleHTTPServer.test(HandlerClass, ServerClass)

if __name__ == '__main__':
    test()
